@@ -256,7 +256,7 @@ class Job:
         assert self.logfile
         updatedAt = os.path.getmtime(self.logfile)
         now = datetime.now().timestamp()
-        self.last_updated_time_in_min = int((now - updatedAt) / 60);
+        self.last_updated_time_in_min = int((now - updatedAt) / 60)
 
     def progress(self):
         '''Return a 2-tuple with the job phase and subphase (by reading the logfile)'''
